@@ -89,7 +89,7 @@ func (e *RunErr) Name() string {
 	if e.Finished == nil {
 		return name
 	}
-	return fmt.Sprintf("%s (%fsec)", name, e.Finished.Sub(*e.Started).Seconds())
+	return fmt.Sprintf("%s (%.3fs)", name, e.Finished.Sub(*e.Started).Seconds())
 }
 
 func (e RunErr) Error() string {
