@@ -24,7 +24,7 @@ import (
 )
 
 const (
-	Version  = "1.4.1"
+	Version  = "1.5.0"
 	Warranty = `Copyright (C) 2020-2021 Sergey Matveev
 
 This program is free software: you can redistribute it and/or modify
@@ -46,7 +46,8 @@ func usage(cmd string) {
 	case "redo":
 		d = `Usage: redo [options] [target ...]
 
-Forcefully and *sequentially* build specified targets.`
+Forcefully and *sequentially* build specified targets.
+If no targets specified, then use "all" one.`
 	case "redo-ifchange":
 		d = `Usage: redo-ifchange target [...]
 
@@ -87,15 +88,15 @@ anyway.`
 Display .do search paths for specified target. Exits successfully
 if the last .do in output if the found existing one.`
 	case "redo-targets":
-		d = `Usage: redo-targets
+		d = `Usage: redo-targets [target ...]
 
 List all currently known targets.`
 	case "redo-sources":
-		d = `Usage: redo-sources
+		d = `Usage: redo-sources [target ...]
 
 List all currently known source files.`
 	case "redo-ood":
-		d = `Usage: redo-ood
+		d = `Usage: redo-ood [target ...]
 
 List all currently known out-of-date targets.`
 	default:
@@ -103,7 +104,8 @@ List all currently known out-of-date targets.`
 
 goredo expects to be called through the symbolic link to it.
 Available commands: redo, redo-always, redo-cleanup, redo-dot,
-redo-ifchange, redo-ifcreate, redo-log, redo-stamp, redo-whichdo.`
+redo-ifchange, redo-ifcreate, redo-log, redo-ood, redo-sources,
+redo-stamp, redo-targets, redo-whichdo.`
 	}
 	fmt.Fprintf(os.Stderr, "%s\n\nCommon options:\n", d)
 	flag.PrintDefaults()
